@@ -63,6 +63,7 @@ class training_class():
         self.visualize_images_per_epoch = False
         self.save_test_images_per_epoch = False
         self.colab_display = False
+        self.result_display = ''
         self.set_params(params_dict)
     def run(self):
         """
@@ -82,6 +83,7 @@ class training_class():
         # start training and result visualization during training period (optional)
         self.train()
 
+
     def prepare_file(self):
         """
         Make data folder to store training results
@@ -332,8 +334,7 @@ class training_class():
               if '.tif' in aaa:
                  result_img_list.append(aaa)
             result_img_list.sort()
-            print('Displaying denoised file of the last epoch: ', result_img_list[-1])
-            display_img(results_path+'/'+result_img_list[-1],norm_min_percent=1, norm_max_percent=99, scale_num=1)
+            self.result_display = results_path+'/'+result_img_list[-1]
 
 
     def save_model(self, epoch, iteration):
